"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const seeds_1 = require("../../seeds");
const seeds_2 = require("../../seeds");
const store_1 = require("../../store");
const utils_1 = require("../../utils");
const messages_1 = require("../messages");
const validators_1 = require("../validators");
exports.default = (inquirer, prevAns = {}, seedList) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    (0, messages_1.appIntro)();
    const { useCurrent, appDirectory = prevAns.appDirectory, appName = prevAns.appName, appSeed, seedDelivery, } = yield inquirer.prompt([
        {
            name: 'useCurrent',
            type: 'confirm',
            message: 'Create an app in current directory',
            when: !prevAns.appDirectory,
            default: true,
        },
        {
            name: 'appDirectory',
            type: 'select-directory',
            message: 'App parent directory',
            when: (data) => !prevAns.appDirectory && !data.useCurrent,
            basePath: utils_1.basePath,
        },
        {
            name: 'appName',
            type: 'input',
            message: 'App name',
            when: !prevAns.appName,
            validate: validators_1.safeName,
        },
        {
            name: 'appSeed',
            type: 'list',
            message: 'App seed',
            choices: (0, utils_1.mapToSeedChoices)(seedList),
        },
        {
            name: 'seedDelivery',
            type: 'list',
            message: 'Seed delivery (Cloning requires an SSH key with a blank passphrase configured for your account)',
            default: seeds_2.SeedDelivery.download,
            choices: [seeds_2.SeedDelivery.download, seeds_2.SeedDelivery.clone],
            when: (data) => !store_1.configStore.values.external && data.appSeed.type !== seeds_1.SeedSource.local,
        },
    ]);
    return {
        useCurrent,
        appDirectory: useCurrent ? process.cwd() : appDirectory,
        appName,
        appSeed,
        seedDelivery,
    };
});
