"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCredentials = exports.setCredentials = exports.authenticateUser = void 0;
const tslib_1 = require("tslib");
const store_1 = require("../../store");
const utils_1 = require("../../utils");
const jfrog_1 = tslib_1.__importDefault(require("../prompts/jfrog"));
const oneMonthInSecs = 2629746;
const expiresISOString = (expiresIn) => {
    const now = new Date();
    now.setSeconds(now.getSeconds() + expiresIn);
    return now.toISOString();
};
const hasExpired = (ISOString) => new Date() > new Date(ISOString);
const recursiveLoginAttempts = (inquirer, prevAns = {}) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const { jfrogUsername, jfrogToken, jfrogTokenExpiry, jfrogTokenType } = prevAns;
    const tokenExpired = jfrogTokenExpiry ? hasExpired(jfrogTokenExpiry) : false;
    if (!jfrogToken || tokenExpired) {
        try {
            const { jfrogUsername: username, jfrogPassword: password } = yield (0, jfrog_1.default)(inquirer, prevAns);
            const basicHttpAuth = Buffer.from(`${username}:${password}`, 'utf-8').toString('base64');
            const tokenReqUsername = username;
            const response = yield (0, utils_1.fetch)('https://genesisglobal.jfrog.io/artifactory/api/security/token', Object.assign(Object.assign({}, (0, utils_1.createDownloadInit)(basicHttpAuth, 'Basic', 'application/x-www-form-urlencoded')), { body: `username=${tokenReqUsername}`, method: 'POST' }));
            if (!response.ok) {
                throw (0, utils_1.responseNotOk)(response, 'Unable to get security token');
            }
            const data = yield response.json();
            utils_1.progressSpinner.succeed(`Logged into Genesis`);
            return {
                jfrogUsername: username,
                jfrogToken: data.access_token,
                jfrogTokenExpiry: expiresISOString(data.expires_in),
                jfrogTokenType: data.token_type,
            };
        }
        catch (error) {
            console.error(error.message);
            // eslint-disable-next-line no-return-await
            return yield recursiveLoginAttempts(inquirer, {});
        }
    }
    else {
        return {
            jfrogUsername,
            jfrogToken,
            jfrogTokenExpiry,
            jfrogTokenType,
        };
    }
});
const applyRuntimeArgs = (prevAns = {}) => {
    if (!prevAns.jfrogUsername) {
        prevAns.jfrogUsername =
            utils_1.argv.jfrogUsername || utils_1.env.GENESISLCAP_JFROG_USERNAME || store_1.configStore.values.jfrog.username;
    }
    if (!prevAns.jfrogPassword) {
        prevAns.jfrogPassword = utils_1.argv.jfrogPassword || utils_1.env.GENESISLCAP_JFROG_PASSWORD;
    }
    if (!prevAns.jfrogToken) {
        prevAns.jfrogToken =
            utils_1.argv.jfrogToken || utils_1.env.GENESISLCAP_JFROG_TOKEN || store_1.configStore.values.jfrog.token;
    }
    if (!prevAns.jfrogTokenExpiry) {
        prevAns.jfrogTokenExpiry =
            utils_1.argv.jfrogTokenExpiry ||
                utils_1.env.GENESISLCAP_JFROG_TOKEN_EXPIRY ||
                store_1.configStore.values.jfrog.tokenExpiry;
    }
    if (!prevAns.jfrogTokenType) {
        prevAns.jfrogTokenType =
            utils_1.argv.jfrogTokenType || utils_1.env.GENESISLCAP_JFROG_TOKEN_TYPE || store_1.configStore.values.jfrog.tokenType;
    }
    return prevAns;
};
const authenticateUser = (inquirer, prevAns = {}) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    prevAns = applyRuntimeArgs(prevAns);
    const credentials = yield recursiveLoginAttempts(inquirer, prevAns);
    return credentials;
});
exports.authenticateUser = authenticateUser;
const setCredentials = (prevAns = {}) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    store_1.configStore.setValue(store_1.configStore.keys.jfrogUsername, prevAns.jfrogUsername);
    store_1.configStore.setValue(store_1.configStore.keys.jfrogToken, prevAns.jfrogToken);
    store_1.configStore.setValue(store_1.configStore.keys.jfrogTokenExpiry, prevAns.jfrogTokenExpiry);
    store_1.configStore.setValue(store_1.configStore.keys.jfrogTokenType, prevAns.jfrogTokenType);
});
exports.setCredentials = setCredentials;
const getCredentials = () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    return ({
        jfrogUsername: store_1.configStore.values.jfrog.username,
        jfrogToken: store_1.configStore.values.jfrog.token,
        jfrogTokenExpiry: store_1.configStore.values.jfrog.tokenExpiry,
        jfrogTokenType: store_1.configStore.values.jfrog.tokenType,
    });
});
exports.getCredentials = getCredentials;
